TransportLinkMetadata

Struct TransportLinkMetadata 

pub struct TransportLinkMetadata {
    pub edge_id: EdgeId,
    pub from_node: NodeId,
    pub to_node: NodeId,
    pub link_class: LinkClass,
    pub allowed_modes: AllowedModes,
    pub traffic_control: Option<TrafficControlType>,
    pub turn_type: Option<TurnType>,
    pub speed_limit_kph: Option<f64>,
}
Minimal reusable transport metadata for a link or edge.

Fields

edge_id: EdgeId

Stable edge identifier.

from_node: NodeId

Source topology node.

to_node: NodeId

Destination topology node.

link_class: LinkClass

Coarse link classification.

allowed_modes: AllowedModes

Which modes may use this link.

traffic_control: Option<TrafficControlType>

Optional traffic control semantics.

turn_type: Option<TurnType>

Optional turn semantics.

speed_limit_kph: Option<f64>

Optional speed limit in km/h.

Implementations

Source

impl TransportLinkMetadata

pub fn new( edge_id: EdgeId, from_node: NodeId, to_node: NodeId, link_class: LinkClass, allowed_modes: AllowedModes, ) -> Self

Create link metadata with a required topology and mode definition.

pub fn with_traffic_control(self, traffic_control: TrafficControlType) -> Self

Attach traffic control semantics.

pub fn with_turn_type(self, turn_type: TurnType) -> Self

Attach turning movement semantics.

pub fn with_speed_limit_kph(self, speed_limit_kph: f64) -> Self

Attach a speed limit in km/h.