pub struct TransportLinkMetadata {
pub edge_id: EdgeId,
pub from_node: NodeId,
pub to_node: NodeId,
pub link_class: LinkClass,
pub allowed_modes: AllowedModes,
pub traffic_control: Option<TrafficControlType>,
pub turn_type: Option<TurnType>,
pub speed_limit_kph: Option<f64>,
}Expand description
Minimal reusable transport metadata for a link or edge.
Fields
edge_id: EdgeIdStable edge identifier.
from_node: NodeIdSource topology node.
to_node: NodeIdDestination topology node.
link_class: LinkClassCoarse link classification.
allowed_modes: AllowedModesWhich modes may use this link.
traffic_control: Option<TrafficControlType>Optional traffic control semantics.
turn_type: Option<TurnType>Optional turn semantics.
speed_limit_kph: Option<f64>Optional speed limit in km/h.
Implementations
Sourceimpl TransportLinkMetadata
impl TransportLinkMetadata
Sourcepub fn new(
edge_id: EdgeId,
from_node: NodeId,
to_node: NodeId,
link_class: LinkClass,
allowed_modes: AllowedModes,
) -> Self
pub fn new( edge_id: EdgeId, from_node: NodeId, to_node: NodeId, link_class: LinkClass, allowed_modes: AllowedModes, ) -> Self
Create link metadata with a required topology and mode definition.
Sourcepub fn with_traffic_control(self, traffic_control: TrafficControlType) -> Self
pub fn with_traffic_control(self, traffic_control: TrafficControlType) -> Self
Attach traffic control semantics.
Sourcepub fn with_turn_type(self, turn_type: TurnType) -> Self
pub fn with_turn_type(self, turn_type: TurnType) -> Self
Attach turning movement semantics.
Sourcepub fn with_speed_limit_kph(self, speed_limit_kph: f64) -> Self
pub fn with_speed_limit_kph(self, speed_limit_kph: f64) -> Self
Attach a speed limit in km/h.